#
# spec file for package python-tokenize-rt
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-tokenize-rt
Version:        6.1.0
Release:        2.1
Summary:        A wrapper around the stdlib `tokenize` which roundtrips
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/asottile/tokenize-rt
Source:         https://github.com/asottile/tokenize-rt/archive/refs/tags/v{%{version}}.tar.gz#/tokenize-rt-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.8}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
%python_subpackages

%description
A wrapper around the stdlib `tokenize` which roundtrips.

%prep
%setup -q -n tokenize-rt-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%{python_clone -a %{buildroot}%{_bindir}/tokenize-rt}
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%post
%python_install_alternative tokenize-rt

%postun
%python_uninstall_alternative tokenize-rt

%check
%pytest

%files %{python_files}
%license LICENSE
%doc README.md
%python_alternative %{_bindir}/tokenize-rt
%{python_sitelib}/tokenize_rt.py
%{python_sitelib}/__pycache__/tokenize_rt*.pyc
%{python_sitelib}/tokenize_rt-%{version}.dist-info

%changelog
* Wed Jun  4 2025 Steve Kowalik <steven.kowalik@suse.com>
- Switch to pyproject macros.
* Sat Nov  9 2024 Dirk Müller <dmueller@suse.com>
- update to 6.1.0:
  * handle unicode named escapes in fstring components
  * add python 3.13
* Mon Oct  7 2024 Dirk Müller <dmueller@suse.com>
- update to 6.0.0:
  * properly handle FSTRING_MIDDLE escaped braces
* Fri Dec  8 2023 Dirk Müller <dmueller@suse.com>
- update to 5.2.0:
  * fix tests for 3.12
  * add Token.matches(*, name, str)
* Fri Aug 11 2023 Sebastian Wagner <sebix@sebix.at>
- update to version 5.1.0:
  - drop support for python 3.7
  - remove no_implicit_optional
  this is the default in mypy 0.990
- update to version 5.0.0:
  - remove python 2 compatible parsing
  - convert pip install comand to a block
  github will produce a copy-paste button
  - remove unused type: ignore
  - Update default branch to main
  - upgrade flake8-typing-imports
  - drop python3.6 support
  python 3.6 reached end of life on 2021-12-23
  - remove --fail-under from tox (covdefaults handles this)
  - improve coverage pragmas with covdefaults 2.1
  - replace exit(main()) with raise SystemExit(main())
* Sun Dec 26 2021 John Vandenberg <jayvdb@gmail.com>
- Use GitHub tarball to activate tests
- Tidy spec
- Update to v4.2.1
  * Fix token offsets following multiline string
- from v4.2.0
  * Fix position of empty NEWLINE at no-eol eof
  * Remove ?s now that offsets are populated
  * Fix UNIMPORTANT_WS offsets for implicit continuation
  * Add offsets for added tokens
- from v4.1.0
  * Add link to future-annotations
  * Add performance hack from python3.10
* Sat Jul  4 2020 Sebastian Wagner <sebix+novell.com@sebix.at>
- initial package for version 4.0.0.
